@@ -18,8 +18,8 @@
 #include "k3bglobals.h"
 #include "k3b_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KConfigCore/KConfigGroup>
+#include <KConfig>
+#include <KConfigGroup>
 #include <QString>
 
 
