@@ -24,8 +24,8 @@
 #include "k3bmixeddoc.h"
 #include "k3bplugin_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KWidgetsAddons/KMessageBox>
+#include <KConfig>
+#include <KMessageBox>
 
 #include <QDebug>
 #include <QFile>
@@ -64,7 +64,7 @@ namespace {
         // to make gcc shut up
         virtual ~K3bMimeTypeResolver() {}
 
-        TagLib::File* createFile( TagLib::FileName fileName, bool, TagLib::AudioProperties::ReadStyle ) const
+        TagLib::File* createFile( TagLib::FileName fileName, bool, TagLib::AudioProperties::ReadStyle ) const override
         {
             QMimeType mimetype = m_mimeDataBase.mimeTypeForFile( QFile::decodeName( fileName ) );
             if ( mimetype.isValid() ) {
