@@ -63,24 +63,24 @@
 #include "option/k3boptiondialog.h"
 #include "projects/k3bdatamultisessionimportdialog.h"
 
-#include <KConfigCore/KConfig>
-#include <KConfigCore/KSharedConfig>
-#include <KConfigWidgets/KRecentFilesAction>
-#include <KConfigWidgets/KStandardAction>
-#include <KCoreAddons/KAboutData>
-#include <KCoreAddons/KProcess>
+#include <KConfig>
+#include <KSharedConfig>
+#include <KRecentFilesAction>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KProcess>
 #include <KLocalizedString>
-#include <KIOCore/KIO/DeleteJob>
-#include <KIOCore/KIO/StatJob>
-#include <KIOCore/KRecentDocument>
-#include <KIOFileWidgets/KFilePlacesModel>
-#include <KWidgetsAddons/KActionMenu>
-#include <KWidgetsAddons/KMessageBox>
-#include <KWidgetsAddons/KToggleAction>
-#include <KXmlGui/KActionCollection>
-#include <KXmlGui/KEditToolBar>
-#include <KXmlGui/KXMLGUIFactory>
-#include <KXmlGui/KShortcutsDialog>
+#include <KIO/DeleteJob>
+#include <KIO/StatJob>
+#include <KRecentDocument>
+#include <KFilePlacesModel>
+#include <KActionMenu>
+#include <KMessageBox>
+#include <KToggleAction>
+#include <KActionCollection>
+#include <KEditToolBar>
+#include <KXMLGUIFactory>
+#include <KShortcutsDialog>
 
 #include <QtAlgorithms>
 #include <QDir>
